==> estateplat-common-1.2.4-20191212.063146-213-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZsCd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产证书裁定
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/12/12
 */
@Table(name = "BDC_ZSCD")
public class BdcZsCd implements Serializable {
    //裁定id
    @Id
    private String cdid;
    //产权证号
    private String cqzh;
    //不动产单元id
    private String bdcdyid;
    //不动产单元号
    private String bdcdyh;
    //项目id
    private String proid;
    //裁定状态
    private String cdzt;
    //裁定原因
    private String cdyy;
    //裁定经办人
    private String cdxmid;
    //裁定时间
    private String cdjbr;
    //解除裁定项目id
    private Date cdsj;
    //解除裁定项目id
    private String jccdxmid;
    //解除裁定经办人
    private String jccdjbr;
    //解除裁定时间
    private String jccdsj;
    //解除裁定原因
    private String jccdyy;
    //备注
    private String bz;

    public String getCdid() {
        return cdid;
    }

    public void setCdid(String cdid) {
        this.cdid = cdid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCdzt() {
        return cdzt;
    }

    public void setCdzt(String cdzt) {
        this.cdzt = cdzt;
    }

    public String getCdyy() {
        return cdyy;
    }

    public void setCdyy(String cdyy) {
        this.cdyy = cdyy;
    }

    public String getCdxmid() {
        return cdxmid;
    }

    public void setCdxmid(String cdxmid) {
        this.cdxmid = cdxmid;
    }

    public String getCdjbr() {
        return cdjbr;
    }

    public void setCdjbr(String cdjbr) {
        this.cdjbr = cdjbr;
    }

    public Date getCdsj() {
        return cdsj;
    }

    public void setCdsj(Date cdsj) {
        this.cdsj = cdsj;
    }

    public String getJccdxmid() {
        return jccdxmid;
    }

    public void setJccdxmid(String jccdxmid) {
        this.jccdxmid = jccdxmid;
    }

    public String getJccdjbr() {
        return jccdjbr;
    }

    public void setJccdjbr(String jccdjbr) {
        this.jccdjbr = jccdjbr;
    }

    public String getJccdsj() {
        return jccdsj;
    }

    public void setJccdsj(String jccdsj) {
        this.jccdsj = jccdsj;
    }

    public String getJccdyy() {
        return jccdyy;
    }

    public void setJccdyy(String jccdyy) {
        this.jccdyy = jccdyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20200421.063638-323-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZsCd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产证书裁定
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/12/12
 */
@Table(name = "BDC_ZSCD")
public class BdcZsCd implements Serializable {
    //裁定id
    @Id
    private String cdid;
    //产权证号
    private String cqzh;
    //不动产单元id
    private String bdcdyid;
    //不动产单元号
    private String bdcdyh;
    //项目id
    private String proid;
    //裁定状态
    private String cdzt;
    //裁定原因
    private String cdyy;
    //裁定经办人
    private String cdxmid;
    //裁定时间
    private String cdjbr;
    //解除裁定项目id
    private Date cdsj;
    //解除裁定项目id
    private String jccdxmid;
    //解除裁定经办人
    private String jccdjbr;
    //解除裁定时间
    private Date jccdsj;
    //解除裁定原因
    private String jccdyy;
    //备注
    private String bz;

    public String getCdid() {
        return cdid;
    }

    public void setCdid(String cdid) {
        this.cdid = cdid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCdzt() {
        return cdzt;
    }

    public void setCdzt(String cdzt) {
        this.cdzt = cdzt;
    }

    public String getCdyy() {
        return cdyy;
    }

    public void setCdyy(String cdyy) {
        this.cdyy = cdyy;
    }

    public String getCdxmid() {
        return cdxmid;
    }

    public void setCdxmid(String cdxmid) {
        this.cdxmid = cdxmid;
    }

    public String getCdjbr() {
        return cdjbr;
    }

    public void setCdjbr(String cdjbr) {
        this.cdjbr = cdjbr;
    }

    public Date getCdsj() {
        return cdsj;
    }

    public void setCdsj(Date cdsj) {
        this.cdsj = cdsj;
    }

    public String getJccdxmid() {
        return jccdxmid;
    }

    public void setJccdxmid(String jccdxmid) {
        this.jccdxmid = jccdxmid;
    }

    public String getJccdjbr() {
        return jccdjbr;
    }

    public void setJccdjbr(String jccdjbr) {
        this.jccdjbr = jccdjbr;
    }

    public Date getJccdsj() {
        return jccdsj;
    }

    public void setJccdsj(Date jccdsj) {
        this.jccdsj = jccdsj;
    }

    public String getJccdyy() {
        return jccdyy;
    }

    public void setJccdyy(String jccdyy) {
        this.jccdyy = jccdyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
